pub struct MutatorHost {
pub mutation_conn: MutationParentConnection,
/* private fields */
}Fields
mutation_conn: MutationParentConnectionImplementations
Sourceimpl MutatorHost
impl MutatorHost
pub async fn connect_and_authenticate( endpoint: &Url, allow_insecure_tls: bool, auth_token: AuthToken, ingest: Option<Client>, ) -> Result<MutatorHost, MutationParentClientInitializationError>
Sourcepub fn disable_mutation_communicated_logging(&mut self)
pub fn disable_mutation_communicated_logging(&mut self)
Disable automatic logging of ‘mutation communicated’ events on the mutator timeline.
Sourcepub fn disable_mutation_inject_and_clear_logging(&mut self)
pub fn disable_mutation_inject_and_clear_logging(&mut self)
Disable automatic logging of mutation injected/cleared events on the mutator host timeline.
You might want to do this if you have arranged to log those events separately, on a timeline that is more directly relevant to system operation.
pub async fn register_mutator( &mut self, mutator: Box<dyn Mutator + Send>, ) -> Result<(), CommsError>
pub async fn message_loop(&mut self) -> Result<(), CommsError>
pub async fn handle_message(&mut self, msg: LeafwardsMessage)